@@ -15,7 +15,7 @@ class PriceVar:
 
     def __init__(self, query_result):
         self.result = query_result
-
+        self.data = self.list_all()
 
     def list_all(self):
         data = []
@@ -37,25 +37,21 @@ class PriceVar:
         return data
 
     def trucker_haul_cost_per_load(self, travel_time):
-        var = self.list_all()
+        var = self.data
         calc = ((((travel_time * var[0]['trips']) * var[0]['car_truck_ratio']) +
                  var[0]['loading_time'] + var[0]['unloading_time']) / 60) * var[0]['hourly_rate']
         return round(calc, 2)
 
     def trucker_haul_cost_per_ton(self, travel_time):
-        var = self.list_all()
-        calc = self.trucker_haul_cost_per_load(travel_time) / var[0]['truck_capacity']
-        return calc
+        var = self.data
+        return self.trucker_haul_cost_per_load(travel_time) / var[0]['truck_capacity']
 
     def trucker_haul_cost_rate(self):
-        var = self.list_all()
+        var = self.data
         return var[0]['hourly_rate']
 
     def customer_haul_price_per_load(self):
         pass
 
     def customer_haul_price_per_ton(self):
-        pass
-
-
-
+        pass
\ No newline at end of file
